=begin
/****************************************************************************
** $Id: application.rb,v 1.1.1.1 2002/12/22 14:19:45 taka-hr Exp $
**
** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
#include <qapplication.h>
#include "application.h"
require "qte"
include Qte
require "qpe"
include Qpe
require "application_lib.rb"

    a = QPEApplication.new( [$0]+ARGV )
    mw = ApplicationWindow.new()
    mw.setCaption( "Document 1" )
    a.showMainWidget(mw)
    Qte::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
    a.exec()

